@@ -303,11 +303,11 @@ class FargateToSnsProps:
         :param vpc_props: Optional custom properties for a VPC the construct will create. This VPC will be used by the new Fargate service the construct creates (that's why targetGroupProps can't include a VPC). Providing both this and existingVpc is an error. An SNS Interface endpoint will be included in this VPC. Default: - none
         '''
         if isinstance(cluster_props, dict):
-            cluster_props = ClusterProps(**cluster_props)
+            cluster_props = aws_cdk.aws_ecs.ClusterProps(**cluster_props)
         if isinstance(topic_props, dict):
-            topic_props = TopicProps(**topic_props)
+            topic_props = aws_cdk.aws_sns.TopicProps(**topic_props)
         if isinstance(vpc_props, dict):
-            vpc_props = VpcProps(**vpc_props)
+            vpc_props = aws_cdk.aws_ec2.VpcProps(**vpc_props)
         if __debug__:
             type_hints = typing.get_type_hints(FargateToSnsProps.__init__)
             check_type(argname="argument public_api", value=public_api, expected_type=type_hints["public_api"])
